@@ -43,12 +43,11 @@
 #' @export
 #' @import utils
 #' @import stats
+#' @import lubridate
 #' @importFrom dplyr left_join
 #' @importFrom readr read_lines
 #' @importFrom readr read_delim
 #' @importFrom readr problems
-#' @importFrom readr parse_number
-#' @importFrom lubridate fast_strptime
 #' @examples
 #' siteNumber <- "02177000"
 #' startDate <- "2012-09-01"
@@ -117,6 +116,11 @@ importRDB1 <- function(obs_url, asDateTime=TRUE, convertType = TRUE, tz=""){
 
   if(convertType){
     readr.data <- suppressWarnings(read_delim(doc, skip = (meta.rows+2),delim="\t",col_names = FALSE))
+  #defaults to time in seconds in readr 0.2.2.9??  
+    if(data.class(readr.data$X4)=="hms"){
+    td <- seconds_to_period(readr.data$X4[!is.na(readr.data$X4)])
+    readr.data$X4[!is.na(readr.data$X4)] <- sprintf('%02d:%02d:%02d', hour(td), minute(td), second(td))
+    }
   } else {
     readr.data <- read_delim(doc, skip = (meta.rows+2),delim="\t",col_names = FALSE, col_types = cols(.default = "c"))
   }
@@ -149,7 +153,7 @@ importRDB1 <- function(obs_url, asDateTime=TRUE, convertType = TRUE, tz=""){
     badCols <- attr(readr.data, "problems")[["col"]]  
     
     if(length(badCols) > 0){
-      readr.data <- fixErrors(readr.data, readr.data.char, "no trailing characters", parse_number)
+      readr.data <- fixErrors(readr.data, readr.data.char, "no trailing characters", as.numeric)
       readr.data <- fixErrors(readr.data, readr.data.char, "date like", parse_date_time, c("%Y-%m-%d %H:%M:%S","%Y-%m-%d","%Y"))
     }
   
@@ -166,9 +170,8 @@ importRDB1 <- function(obs_url, asDateTime=TRUE, convertType = TRUE, tz=""){
         
         if(all(c(paste0(i,"_dt"),paste0(i,"_tm")) %in% header.names)){
           varname <- paste0(i,"_dateTime")
-          
-          varval <- fast_strptime(paste(readr.data[,paste0(i,"_dt")],readr.data[,paste0(i,"_tm")]), "%Y-%m-%d %H:%M", tz = "UTC", lt=FALSE)
-          
+          varval <- parse_date_time(paste(readr.data[,paste0(i,"_dt")],readr.data[,paste0(i,"_tm")]), c("%Y-%m-%d %H:%M:%S","%Y-%m-%d %H:%M"), tz = "UTC")
+        
           if(!all(is.na(varval))){
             readr.data[,varname] <- varval
             tz.name <- paste0(i,"_time_datum_cd")
@@ -181,7 +184,7 @@ importRDB1 <- function(obs_url, asDateTime=TRUE, convertType = TRUE, tz=""){
             
             if(tz.name %in% header.names){
               readr.data <- convertTZ(readr.data,tz.name,varname,tz)
-            } 
+            }
           }
         }
       }
@@ -199,7 +202,7 @@ importRDB1 <- function(obs_url, asDateTime=TRUE, convertType = TRUE, tz=""){
       
       if(all(c("DATE","TIME","TZCD") %in% header.names)){
         varname <- "DATETIME"
-        varval <- fast_strptime(paste(readr.data[,"DATE"],readr.data[,"TIME"]), "%Y-%m-%d %H%M%S", tz = "UTC", lt=FALSE)
+        varval <- as.POSIXct(fast_strptime(paste(readr.data[,"DATE"],readr.data[,"TIME"]), "%Y-%m-%d %H%M%S", tz = "UTC"))
         readr.data[,varname] <- varval
         readr.data <- convertTZ(readr.data,"TZCD",varname,tz, flip.cols=TRUE)
       }
