@@ -5,6 +5,7 @@
 #'
 #' @param \dots see \url{www.waterqualitydata.us/webservices_documentation.jsp} for a complete list of options
 #' @param zip logical to request data via downloading zip file. Default set to FALSE.
+#' @param querySummary logical to ONLY return the number of records and unique sites that will be returned from this query.
 #' @keywords data import WQP web service
 #' @return A data frame with at least the following columns:
 #' \tabular{lll}{ 
@@ -90,14 +91,15 @@
 #' \dontrun{
 #' nameToUse <- "pH"
 #' pHData <- readWQPdata(siteid="USGS-04024315",characteristicName=nameToUse)
-#' pHDataExpanded2 <- readWQPdata(bBox=c(-90.10,42.67,-88.64,43.35),characteristicName=nameToUse)
+#' pHData_summary <- readWQPdata(bBox=c(-90.10,42.67,-88.64,43.35),
+#'      characteristicName=nameToUse, querySummary=TRUE)
 #' startDate <- as.Date("2013-01-01")
 #' nutrientDaneCounty <- readWQPdata(countycode="US:55:025",startDate=startDate,
 #'                         characteristicType="Nutrient")
 #' 
 #'                         
 #' }
-readWQPdata <- function(..., zip=FALSE){
+readWQPdata <- function(..., zip=FALSE, querySummary=FALSE){
   
   matchReturn <- list(...)
 
@@ -154,53 +156,59 @@ readWQPdata <- function(..., zip=FALSE){
   
   if(zip) urlCall <- paste0(urlCall,"&zip=yes")
   
-  retval <- importWQP(urlCall,zip=zip, tz=tz)
-  
-  if(!all(is.na(retval))){
-    siteInfo <- whatWQPsites(...,zip=zip)
-    
-    siteInfoCommon <- data.frame(station_nm=siteInfo$MonitoringLocationName,
-                                 agency_cd=siteInfo$OrganizationIdentifier,
-                                 site_no=siteInfo$MonitoringLocationIdentifier,
-                                 dec_lat_va=siteInfo$LatitudeMeasure,
-                                 dec_lon_va=siteInfo$LongitudeMeasure,
-                                 hucCd=siteInfo$HUCEightDigitCode,
-                                 stringsAsFactors=FALSE)
-    
-    siteInfo <- cbind(siteInfoCommon, siteInfo)
-    
-    retvalVariableInfo <- retval[,c("CharacteristicName","USGSPCode",
-                                    "ResultMeasure.MeasureUnitCode","ResultSampleFractionText")]
-    retvalVariableInfo <- unique(retvalVariableInfo)
-    
-    variableInfo <- data.frame(characteristicName=retval$CharacteristicName,
-                               parameterCd=retval$USGSPCode,
-                               param_units=retval$ResultMeasure.MeasureUnitCode,
-                               valueType=retval$ResultSampleFractionText,
-                               stringsAsFactors=FALSE)
-    
-    if(any(!is.na(variableInfo$parameterCd))){
-      pcodes <- unique(variableInfo$parameterCd[!is.na(variableInfo$parameterCd)])
-      pcodes <- pcodes["" != pcodes]
-      paramINFO <- readNWISpCode(pcodes)
-      names(paramINFO)["parameter_cd" == names(paramINFO)] <- "parameterCd"
-      
-      pCodeToName <- pCodeToName
-      varExtras <- pCodeToName[pCodeToName$parm_cd %in% unique(variableInfo$parameterCd[!is.na(variableInfo$parameterCd)]),]
-      names(varExtras)[names(varExtras) == "parm_cd"] <- "parameterCd"
-      variableInfo <- merge(variableInfo, varExtras, by="parameterCd", all = TRUE)
-      variableInfo <- merge(variableInfo, paramINFO, by="parameterCd", all = TRUE)
-      variableInfo <- unique(variableInfo)
-    }
-    
-    attr(retval, "siteInfo") <- siteInfo
-    attr(retval, "variableInfo") <- variableInfo
-    attr(retval, "url") <- urlCall
-    attr(retval, "queryTime") <- Sys.time()
-    
-    return(retval)
+  if(querySummary){
+    retquery <- getQuerySummary(urlCall)
+    return(retquery)
   } else {
-    message("The following url returned no data:\n")
-    message(urlCall)
+  
+    retval <- importWQP(urlCall,zip=zip, tz=tz)
+    
+    if(!all(is.na(retval))){
+      siteInfo <- whatWQPsites(...,zip=zip)
+      
+      siteInfoCommon <- data.frame(station_nm=siteInfo$MonitoringLocationName,
+                                   agency_cd=siteInfo$OrganizationIdentifier,
+                                   site_no=siteInfo$MonitoringLocationIdentifier,
+                                   dec_lat_va=siteInfo$LatitudeMeasure,
+                                   dec_lon_va=siteInfo$LongitudeMeasure,
+                                   hucCd=siteInfo$HUCEightDigitCode,
+                                   stringsAsFactors=FALSE)
+      
+      siteInfo <- cbind(siteInfoCommon, siteInfo)
+      
+      retvalVariableInfo <- retval[,c("CharacteristicName","USGSPCode",
+                                      "ResultMeasure.MeasureUnitCode","ResultSampleFractionText")]
+      retvalVariableInfo <- unique(retvalVariableInfo)
+      
+      variableInfo <- data.frame(characteristicName=retval$CharacteristicName,
+                                 parameterCd=retval$USGSPCode,
+                                 param_units=retval$ResultMeasure.MeasureUnitCode,
+                                 valueType=retval$ResultSampleFractionText,
+                                 stringsAsFactors=FALSE)
+      
+      if(any(!is.na(variableInfo$parameterCd))){
+        pcodes <- unique(variableInfo$parameterCd[!is.na(variableInfo$parameterCd)])
+        pcodes <- pcodes["" != pcodes]
+        paramINFO <- readNWISpCode(pcodes)
+        names(paramINFO)["parameter_cd" == names(paramINFO)] <- "parameterCd"
+        
+        pCodeToName <- pCodeToName
+        varExtras <- pCodeToName[pCodeToName$parm_cd %in% unique(variableInfo$parameterCd[!is.na(variableInfo$parameterCd)]),]
+        names(varExtras)[names(varExtras) == "parm_cd"] <- "parameterCd"
+        variableInfo <- merge(variableInfo, varExtras, by="parameterCd", all = TRUE)
+        variableInfo <- merge(variableInfo, paramINFO, by="parameterCd", all = TRUE)
+        variableInfo <- unique(variableInfo)
+      }
+      
+      attr(retval, "siteInfo") <- siteInfo
+      attr(retval, "variableInfo") <- variableInfo
+      attr(retval, "url") <- urlCall
+      attr(retval, "queryTime") <- Sys.time()
+      
+      return(retval)
+    } else {
+      message("The following url returned no data:\n")
+      message(urlCall)
+    }
   }
 }
\ No newline at end of file
